#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hoogle
version:              5.0.18.4
visibility:           public
id:                   hoogle-5.0.18.4-Kblb609U6KPAtzQQgNEHr0
key:                  hoogle-5.0.18.4-Kblb609U6KPAtzQQgNEHr0
license:              BSD-3-Clause
copyright:            Neil Mitchell 2004-2024
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://hoogle.haskell.org/
synopsis:             Haskell API Search
description:
    Hoogle is a Haskell API search engine, which allows you to
    search many standard Haskell libraries by either function name,
    or by approximate type signature.

category:             Development
abi:                  602cecd3c7074a1eb3e50f2e0731318f
exposed:              True
exposed-modules:      Hoogle
hidden-modules:
    Paths_hoogle Action.CmdLine Action.Generate Action.Search
    Action.Server Action.Test Input.Cabal Input.Download Input.Haddock
    Input.Item Input.Reorder Input.Set Input.Settings Output.Items
    Output.Names Output.Tags Output.Types Query General.Conduit
    General.IString General.Log General.Store General.Str
    General.Template General.Timing General.Util General.Web

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hoogle-5.0.18.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hoogle-5.0.18.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hoogle-5.0.18.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hoogle
hs-libraries:         HShoogle-5.0.18.4-Kblb609U6KPAtzQQgNEHr0
include-dirs:         /usr/lib/ghc-9.6.6/site-local/hoogle-5.0.18.4/include
includes:             include.h
depends:
    QuickCheck-2.15.0.1-3mU9ZiusQQy5d3HGk3bpZl
    aeson-2.2.2.0-EwrTYsTfELe3d4orbILmv4 base-4.18.2.1 binary-0.8.9.1
    blaze-html-0.9.2.0-IQpYWAMPsDd8u1EAzkbal7
    blaze-markup-0.8.3.0-8LKEXVAssOfaSB46gmUNg bytestring-0.11.5.3
    cmdargs-0.10.22-E2EkQI5shziHkHOdPiVHiM
    conduit-1.3.6.1-KPHDCDDIHN1EOURpcrFXUe
    conduit-extra-1.3.8-1lTAw5MbR9d8jW8YQMIELA containers-0.6.7
    crypton-connection-0.4.5-5TQcXZGYymW740sXW0z8oC deepseq-1.4.8.1
    directory-1.3.8.5 extra-1.7.16-J2nH1si97LP2pkcRW1gnIU
    filepath-1.4.300.1 foundation-0.0.30-6skbgXTSSMQ6lxsCo3UqmT
    hashable-1.4.7.0-8JCT2FqI0OIc7eryHiY9E
    haskell-src-exts-1.23.1-3JlEDY0GlvbDl9TOFDgSoA
    http-conduit-2.3.9.1-3jVRXfysx7LHah4LOBTB7z
    http-types-0.12.4-D4ln0jiwEOhAKcR3fqSchY
    js-flot-0.8.3-CSwWF2xMOrpIfADJpYok8C
    js-jquery-3.7.1-BwP2iJ0bX0HCp9pnNzYxYK
    mmap-0.5.9-AiaaDT3AznV3aaEfoYTVVt
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    process-extras-0.7.4-3BZMuov4kqQ5D1DQvrWS6d
    resourcet-1.3.0-1zDmXgfXfhGHcZ53EkSGgY
    safe-0.3.21-CNekTOvlOCxBWhpb53aZQe
    storable-tuple-0.1-A6P1yuVK31n2L7xIF0j6x5
    tar-0.6.0.0-2AlYzEPApJf7TzoUIkXY6Y template-haskell-2.20.0.0
    text-2.0.2 time-1.12.2 transformers-0.6.1.0
    uniplate-1.6.13-AzjlWyYh2ZSH2gzxES4aea
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    vector-0.13.2.0-pkGAkHyCfVA94J1hIBHJi
    wai-3.2.4-HOJRNxSLXyTJ5Lq7jmcw5j
    wai-logger-2.5.0-7jaK26jiMc12IMOSSvGTfU
    warp-3.4.0-KIEmCyfVmmO5GM68R2rzXC
    warp-tls-3.4.9-FrYwUUZT6gG5afnUN4OZqy
    zlib-0.7.1.0-JUvXnJeECOb5UrlPGbJucV

haddock-interfaces:   /usr/share/doc/hoogle/html/hoogle.haddock
haddock-html:         /usr/share/doc/hoogle/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

